package com.ssm.manage.mapper;

import com.ssm.core.mapper.BaseMapper;
import com.ssm.manage.entity.Routing;
import com.ssm.manage.entity.SysMenuPower;
import com.ssm.manage.entity.SysRolePower;
import com.ssm.manage.query.RoutingListRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@Component
public interface RoutingMapper extends BaseMapper<Routing> {
    List<Routing> selectPage(RoutingListRequest routingListRequest);
    List<Routing> selectSuperid(RoutingListRequest routingListRequest);
    int updateId(@RequestParam("list") List<Routing> list,@RequestParam("memberName") String memberName);
    int deleteID(@RequestParam("list") List<Routing> list);

    //查询插入ID是否重复
    List<Routing> selectDvalue(RoutingListRequest routingListRequest);
    List<SysRolePower> selectDvalue1(SysRolePower sysRolePower);
    List<SysMenuPower> selectDvalue2(SysMenuPower sysMenuPower);
    //查询路径是否重复
    List<Routing> selectPath(RoutingListRequest routingListRequest);
    int add1(RoutingListRequest routingListRequest);
    int add2(RoutingListRequest routingListRequest);
    int deleteID1(@RequestParam("id") Long id);
    int deleteID2(@RequestParam("powerId") Long powerId);
    int updateId1(@RequestParam("memberName") String memberName,@RequestParam("powerId") Long id);
}
